<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'ICal' => array($vendorDir . '/johngrogg/ics-parser/src'),
    'HTMLPurifier' => array($vendorDir . '/ezyang/htmlpurifier/library'),
    'Evenement' => array($vendorDir . '/evenement/evenement/src'),
);
