<?php return array(
    'root' => array(
        'name' => 'espocrm/espocrm',
        'pretty_version' => 'dev-master',
        'version' => 'dev-master',
        'reference' => '9a013b7ea727777041ea6296dc8295b5bb4d0d3b',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'async-aws/core' => array(
            'pretty_version' => '1.9.1',
            'version' => '1.9.1.0',
            'reference' => '7c623f72aba439d514742c1476a803c7b4311cc8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../async-aws/core',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'async-aws/s3' => array(
            'pretty_version' => '1.8.0',
            'version' => '1.8.0.0',
            'reference' => '6da98edfe96fa4777d3a5eb2c95ec19ef0d6376c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../async-aws/s3',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cboden/ratchet' => array(
            'pretty_version' => 'v0.4.4',
            'version' => '0.4.4.0',
            'reference' => '5012dc954541b40c5599d286fd40653f5716a38f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../cboden/ratchet',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'composer/semver' => array(
            'pretty_version' => '3.0.0',
            'version' => '3.0.0.0',
            'reference' => '3426bd5efa8a12d230824536c42a8a4ad30b7940',
            'type' => 'library',
            'install_path' => __DIR__ . '/./semver',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'container-interop/container-interop' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '^1.2.0',
            ),
        ),
        'doctrine/cache' => array(
            'pretty_version' => '2.1.1',
            'version' => '2.1.1.0',
            'reference' => '331b4d5dbaeab3827976273e9356b3b453c300ce',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/dbal' => array(
            'pretty_version' => '3.5.3',
            'version' => '3.5.3.0',
            'reference' => '88fa7e5189fd5ec6682477044264dc0ed4e3aa1e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/dbal',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/deprecations' => array(
            'pretty_version' => 'v0.5.3',
            'version' => '0.5.3.0',
            'reference' => '9504165960a1f83cc1480e2be1dd0a0478561314',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/deprecations',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/event-manager' => array(
            'pretty_version' => '1.1.1',
            'version' => '1.1.1.0',
            'reference' => '41370af6a30faa9dc0368c4a6814d596e81aba7f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/event-manager',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dompdf/dompdf' => array(
            'pretty_version' => 'v2.0.3',
            'version' => '2.0.3.0',
            'reference' => 'e8d2d5e37e8b0b30f0732a011295ab80680d7e85',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dompdf/dompdf',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dragonmantank/cron-expression' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => '48212cdc0a79051d50d7fc2f0645c5a321caf926',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dragonmantank/cron-expression',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'espocrm/espocrm' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '9a013b7ea727777041ea6296dc8295b5bb4d0d3b',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'evenement/evenement' => array(
            'pretty_version' => 'v3.0.1',
            'version' => '3.0.1.0',
            'reference' => '531bfb9d15f8aa57454f5f0285b18bec903b8fb7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../evenement/evenement',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ezyang/htmlpurifier' => array(
            'pretty_version' => 'v4.13.0',
            'version' => '4.13.0.0',
            'reference' => '08e27c97e4c6ed02f37c5b2b20488046c8d90d75',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ezyang/htmlpurifier',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fig/http-message-util' => array(
            'pretty_version' => '1.1.5',
            'version' => '1.1.5.0',
            'reference' => '9d94dc0154230ac39e5bf89398b324a86f63f765',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fig/http-message-util',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '1.9.1',
            'version' => '1.9.1.0',
            'reference' => 'e4490cabc77465aaee90b20cfc9a770f8c04be6b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'johngrogg/ics-parser' => array(
            'pretty_version' => 'v3.0.0',
            'version' => '3.0.0.0',
            'reference' => 'c74f5881198760386f243d6b1e090e54952ac825',
            'type' => 'library',
            'install_path' => __DIR__ . '/../johngrogg/ics-parser',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-crypt' => array(
            'pretty_version' => '3.9.0',
            'version' => '3.9.0.0',
            'reference' => '56ab1b195dad5456753601ff2e8e3d3fd9392d1a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-crypt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-ldap' => array(
            'pretty_version' => '2.16.0',
            'version' => '2.16.0.0',
            'reference' => '4c1fefb3dad9b112e18a7d35245854dc77a04a1e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-ldap',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-loader' => array(
            'pretty_version' => '2.9.0',
            'version' => '2.9.0.0',
            'reference' => '51ed9c3fa42d1098a9997571730c0cbf42d078d3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-loader',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-mail' => array(
            'pretty_version' => '2.20.0',
            'version' => '2.20.0.0',
            'reference' => '0516586f6bf4d47f855cbef040870ac3a324a9a8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-mail',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-math' => array(
            'pretty_version' => '3.6.0',
            'version' => '3.6.0.0',
            'reference' => '5770fc632a3614f5526632a8b70f41b65130460e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-mime' => array(
            'pretty_version' => '2.11.0',
            'version' => '2.11.0.0',
            'reference' => '60ec04b755821c79c1987ce291b44e69f2c0831f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-mime',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-servicemanager' => array(
            'pretty_version' => '3.19.0',
            'version' => '3.19.0.0',
            'reference' => 'ed160729bb8721127efdaac799f9a298963345b1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-servicemanager',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-stdlib' => array(
            'pretty_version' => '3.15.0',
            'version' => '3.15.0.0',
            'reference' => '63b66bd4b696f024f42616b9d95cdb10e5109c27',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-stdlib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laminas/laminas-validator' => array(
            'pretty_version' => '2.28.0',
            'version' => '2.28.0.0',
            'reference' => '695bfa40b0a83dc1c5c58bdf74a03fdbeb516c39',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laminas/laminas-validator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laravel/serializable-closure' => array(
            'pretty_version' => 'v1.2.2',
            'version' => '1.2.2.0',
            'reference' => '47afb7fae28ed29057fdca37e16a84f90cc62fae',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laravel/serializable-closure',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/flysystem' => array(
            'pretty_version' => '2.1.1',
            'version' => '2.1.1.0',
            'reference' => 'a3c694de9f7e844b76f9d1b61296ebf6e8d89d74',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/flysystem',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/flysystem-async-aws-s3' => array(
            'pretty_version' => '2.0.4',
            'version' => '2.0.4.0',
            'reference' => '2a2e566cf1dae8e0ebfca49c6eda8050935d1c0d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/flysystem-async-aws-s3',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/mime-type-detection' => array(
            'pretty_version' => '1.7.0',
            'version' => '1.7.0.0',
            'reference' => '3b9dff8aaf7323590c1d2e443db701eb1f9aa0d3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/mime-type-detection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'maennchen/zipstream-php' => array(
            'pretty_version' => '2.1.0',
            'version' => '2.1.0.0',
            'reference' => 'c4c5803cc1f93df3d2448478ef79394a5981cc58',
            'type' => 'library',
            'install_path' => __DIR__ . '/../maennchen/zipstream-php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'markbaker/complex' => array(
            'pretty_version' => '2.0.0',
            'version' => '2.0.0.0',
            'reference' => '9999f1432fae467bc93c53f357105b4c31bb994c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../markbaker/complex',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'markbaker/matrix' => array(
            'pretty_version' => '2.1.2',
            'version' => '2.1.2.0',
            'reference' => '361c0f545c3172ee26c3d596a0aa03f0cef65e6a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../markbaker/matrix',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'masterminds/html5' => array(
            'pretty_version' => '2.7.6',
            'version' => '2.7.6.0',
            'reference' => '897eb517a343a2281f11bc5556d6548db7d93947',
            'type' => 'library',
            'install_path' => __DIR__ . '/../masterminds/html5',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'michelf/php-markdown' => array(
            'pretty_version' => '1.9.0',
            'version' => '1.9.0.0',
            'reference' => 'c83178d49e372ca967d1a8c77ae4e051b3a3c75c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../michelf/php-markdown',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'monolog/monolog' => array(
            'pretty_version' => '2.1.1',
            'version' => '2.1.1.0',
            'reference' => 'f9eee5cec93dfb313a38b6b288741e84e53f02d5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../monolog/monolog',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mtdowling/cron-expression' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '^1.0',
            ),
        ),
        'myclabs/php-enum' => array(
            'pretty_version' => '1.7.7',
            'version' => '1.7.7.0',
            'reference' => 'd178027d1e679832db9f38248fcc7200647dc2b7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../myclabs/php-enum',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nesbot/carbon' => array(
            'pretty_version' => '2.62.1',
            'version' => '2.62.1.0',
            'reference' => '01bc4cdefe98ef58d1f9cb31bdbbddddf2a88f7a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nesbot/carbon',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nikic/fast-route' => array(
            'pretty_version' => 'v1.3.0',
            'version' => '1.3.0.0',
            'reference' => '181d480e08d9476e61381e04a71b34dc0432e812',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nikic/fast-route',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'openspout/openspout' => array(
            'pretty_version' => 'v4.9.0',
            'version' => '4.9.0.0',
            'reference' => '7b0db352e25c83e42d3375f57041a30a1ea9cd2c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../openspout/openspout',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'paragonie/constant_time_encoding' => array(
            'pretty_version' => 'v2.6.3',
            'version' => '2.6.3.0',
            'reference' => '58c3f47f650c94ec05a151692652a868995d2938',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/constant_time_encoding',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'paragonie/random_compat' => array(
            'pretty_version' => 'v9.99.100',
            'version' => '9.99.100.0',
            'reference' => '996434e5492cb4c3edcb9168db6fbb1359ef965a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../paragonie/random_compat',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phenx/php-font-lib' => array(
            'pretty_version' => '0.5.4',
            'version' => '0.5.4.0',
            'reference' => 'dd448ad1ce34c63d09baccd05415e361300c35b4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phenx/php-font-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phenx/php-svg-lib' => array(
            'pretty_version' => '0.5.0',
            'version' => '0.5.0.0',
            'reference' => '76876c6cf3080bcb6f249d7d59705108166a6685',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phenx/php-svg-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/async-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
            ),
        ),
        'php-http/client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
            ),
        ),
        'phpoffice/phpspreadsheet' => array(
            'pretty_version' => '1.16.0',
            'version' => '1.16.0.0',
            'reference' => '76d4323b85129d0c368149c831a07a3e258b2b50',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpoffice/phpspreadsheet',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpseclib/phpseclib' => array(
            'pretty_version' => '3.0.19',
            'version' => '3.0.19.0',
            'reference' => 'cc181005cf548bfd8a4896383bb825d859259f95',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpseclib/phpseclib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpspec/prophecy' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'psr/cache' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => 'd11b50ad223250cf17b86e38383413f5a6764bf8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/container' => array(
            'pretty_version' => '1.1.2',
            'version' => '1.1.2.0',
            'reference' => '513e0666f7216c7459170d56df27dfcefe1689ea',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/container',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/container-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '^1.0',
            ),
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '2dfb5f6c5eff0e91e20e913f8c5452ed95b86621',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.0.2',
            'version' => '1.0.2.0',
            'reference' => 'e616d01114759c4c489f93b099585439f795fe35',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.1',
            'version' => '1.1.0.0',
            'reference' => 'cb6ce4845ce34a8ad9e68117c10ee90a29919eba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-server-handler' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => 'aff2f80e33b7f026ec96bb42f63242dc50ffcae7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-server-handler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-server-middleware' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '2296f45510945530b9dceb8bcedb5cb84d40c5f5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-server-middleware',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0.0',
            ),
        ),
        'psr/simple-cache' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '408d5eafb83c57f6365a3ca330ff23aa4a5fa39b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/simple-cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ratchet/rfc6455' => array(
            'pretty_version' => 'v0.3.1',
            'version' => '0.3.1.0',
            'reference' => '7c964514e93456a52a99a20fcfa0de242a43ccdb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ratchet/rfc6455',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/cache' => array(
            'pretty_version' => 'v1.2.0',
            'version' => '1.2.0.0',
            'reference' => 'd47c472b64aa5608225f47965a484b75c7817d5b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/dns' => array(
            'pretty_version' => 'v1.11.0',
            'version' => '1.11.0.0',
            'reference' => '3be0fc8f1eb37d6875cd6f0c6c7d0be81435de9f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/dns',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/event-loop' => array(
            'pretty_version' => 'v1.4.0',
            'version' => '1.4.0.0',
            'reference' => '6e7e587714fff7a83dcc7025aee42ab3b265ae05',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/event-loop',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/promise' => array(
            'pretty_version' => 'v2.10.0',
            'version' => '2.10.0.0',
            'reference' => 'f913fb8cceba1e6644b7b90c4bfb678ed8a3ef38',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/promise',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/socket' => array(
            'pretty_version' => 'v1.13.0',
            'version' => '1.13.0.0',
            'reference' => 'cff482bbad5848ecbe8b57da57e4e213b03619aa',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/socket',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/stream' => array(
            'pretty_version' => 'v1.3.0',
            'version' => '1.3.0.0',
            'reference' => '6fbc9672905c7d5a885f2da2fc696f65840f4a66',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/stream',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/zmq' => array(
            'pretty_version' => 'v0.4.0',
            'version' => '0.4.0.0',
            'reference' => '13dec0bd2397adcc5d6aa54c8d7f0982fba66f39',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/zmq',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'robthree/twofactorauth' => array(
            'pretty_version' => '1.6.7',
            'version' => '1.6.7.0',
            'reference' => '3407c33775391fa8c36f7d766f26c5e59a736374',
            'type' => 'library',
            'install_path' => __DIR__ . '/../robthree/twofactorauth',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabberworm/php-css-parser' => array(
            'pretty_version' => '8.4.0',
            'version' => '8.4.0.0',
            'reference' => 'e41d2140031d533348b2192a83f02d8dd8a71d30',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabberworm/php-css-parser',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'slim/psr7' => array(
            'pretty_version' => '1.6.1',
            'version' => '1.6.1.0',
            'reference' => '72d2b2bac94ab4575d369f605dbfafbe168d3163',
            'type' => 'library',
            'install_path' => __DIR__ . '/../slim/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'slim/slim' => array(
            'pretty_version' => '4.11.0',
            'version' => '4.11.0.0',
            'reference' => 'b0f4ca393ea037be9ac7292ba7d0a34d18bac0c7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../slim/slim',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'spatie/async' => array(
            'pretty_version' => '1.5.6',
            'version' => '1.5.6.0',
            'reference' => '24a8ffa98f4fe0f9dc5daef3bab02a65729fe23b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../spatie/async',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v2.5.2',
            'version' => '2.5.2.0',
            'reference' => 'e8b495ea28c1d97b5e0c121748d6f9b53d075c66',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client' => array(
            'pretty_version' => 'v5.2.3',
            'version' => '5.2.3.0',
            'reference' => '22cb1a7844fff206cc5186409776e78865405ea5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client-contracts' => array(
            'pretty_version' => 'v2.3.1',
            'version' => '2.3.1.0',
            'reference' => '41db680a15018f9c1d4b23516059633ce280ca33',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-client-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.1',
            ),
        ),
        'symfony/http-foundation' => array(
            'pretty_version' => 'v6.0.20',
            'version' => '6.0.20.0',
            'reference' => 'e16b2676a4b3b1fa12378a20b29c364feda2a8d6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-foundation',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-iconv' => array(
            'pretty_version' => 'v1.20.0',
            'version' => '1.20.0.0',
            'reference' => 'c536646fdb4f29104dd26effc2fdcb9a5b085024',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-iconv',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-idn' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '639084e360537a19f9ee352433b84ce831f3d2da',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-idn',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-normalizer' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '19bd1e4fcd5b91116f14d8533c57831ed00571b6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-normalizer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '8ad114f6b39e2c98a8b0e3bd907732c207c2b534',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php72' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '869329b1e9894268a8a61dabb69153029b7a8c97',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php72',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php73' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '9e8ecb5f92152187c4799efd3c96b78ccab18ff9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php73',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '7a6ff3f1959bb01aefccb463a0f2cd3d3d2fd936',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/process' => array(
            'pretty_version' => 'v6.0.19',
            'version' => '6.0.19.0',
            'reference' => '2114fd60f26a296cc403a7939ab91478475a33d4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/process',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/routing' => array(
            'pretty_version' => 'v6.0.19',
            'version' => '6.0.19.0',
            'reference' => 'e56ca9b41c1ec447193474cd86ad7c0b547755ac',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/routing',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/service-contracts' => array(
            'pretty_version' => 'v2.2.0',
            'version' => '2.2.0.0',
            'reference' => 'd15da7ba4957ffb8f1747218be9e1a121fd298a1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/service-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation' => array(
            'pretty_version' => 'v4.4.25',
            'version' => '4.4.25.0',
            'reference' => 'dfe132c5c6d89f90ce7f961742cc532e9ca16dd4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/translation',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation-contracts' => array(
            'pretty_version' => 'v2.4.0',
            'version' => '2.4.0.0',
            'reference' => '95c812666f3e91db75385749fe219c5e494c7f95',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/translation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0|2.0',
            ),
        ),
        'tecnickcom/tcpdf' => array(
            'pretty_version' => '6.3.5',
            'version' => '6.3.5.0',
            'reference' => '19a535eaa7fb1c1cac499109deeb1a7a201b4549',
            'type' => 'library',
            'install_path' => __DIR__ . '/../tecnickcom/tcpdf',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'webmozart/assert' => array(
            'pretty_version' => '1.11.0',
            'version' => '1.11.0.0',
            'reference' => '11cb2199493b2f8a3b53e7f19068fc6aac760991',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/assert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'yzalis/identicon' => array(
            'pretty_version' => '2.0.0',
            'version' => '2.0.0.0',
            'reference' => 'ff5ed090129cab9bfa2a322857d4a01d107aa0ae',
            'type' => 'library',
            'install_path' => __DIR__ . '/../yzalis/identicon',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'zbateson/mail-mime-parser' => array(
            'pretty_version' => '1.3.1',
            'version' => '1.3.1.0',
            'reference' => '706964d904798b8c22d63f62f0ec5f5bc84e30d9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../zbateson/mail-mime-parser',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'zbateson/mb-wrapper' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '721b3dfbf7ab75fee5ac60a542d7923ffe59ef6d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../zbateson/mb-wrapper',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'zbateson/stream-decorators' => array(
            'pretty_version' => '1.0.4',
            'version' => '1.0.4.0',
            'reference' => '6f54738dfecc65e1d5bfb855035836748083a6dd',
            'type' => 'library',
            'install_path' => __DIR__ . '/../zbateson/stream-decorators',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'zordius/lightncandy' => array(
            'pretty_version' => 'dev-espo',
            'version' => 'dev-espo',
            'reference' => '207d424c4ced34644663fdc0758c19d5b6974adc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../zordius/lightncandy',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
